pub trait FromUnshared<Unshared> {
// Required method
fn from_unshared(value: Unshared) -> Self;
}Expand description
Like the From trait, but for converting to a shared type.
See the module docs for information about shared types.
Required Methods
Creates a shared type from an unshared type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".